@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V7::ReportingService::AgeGenderDemographicReportColumn;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -26,6 +26,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
     EstimatedCtr
     EstimatedImpressionPercent
     Gender
+    Language
     LanguageAndRegion
     TimePeriod
 
@@ -71,6 +72,10 @@ sub Gender {
     return 'Gender';
 }
 
+sub Language {
+    return 'Language';
+}
+
 sub LanguageAndRegion {
     return 'LanguageAndRegion';
 }
