@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V7::ReportingService::DestinationUrlPerformanceReportColumn;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -36,6 +36,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
     DestinationUrl
     DeviceType
     Impressions
+    Language
     LanguageAndRegion
     PricingModel
     Spend
@@ -123,6 +124,10 @@ sub Impressions {
     return 'Impressions';
 }
 
+sub Language {
+    return 'Language';
+}
+
 sub LanguageAndRegion {
     return 'LanguageAndRegion';
 }
