@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V7::ReportingService::PublisherUsagePerformanceReportColumn;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -34,6 +34,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
     Ctr
     CurrencyCode
     Impressions
+    Language
     LanguageAndRegion
     PricingModel
     PublisherUrl
@@ -114,6 +115,10 @@ sub Impressions {
     return 'Impressions';
 }
 
+sub Language {
+    return 'Language';
+}
+
 sub LanguageAndRegion {
     return 'LanguageAndRegion';
 }
