@@ -30,7 +30,10 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
     CurrencyCode
     DeviceOS
     DeviceType
+    ImpressionLostToBidPercent
     ImpressionLostToBudgetPercent
+    ImpressionLostToKeywordRelevancePercent
+    ImpressionLostToLandingPageRelevancePercent
     ImpressionLostToOthersPercent
     ImpressionLostToRankPercent
     ImpressionLostToRelevancePercent
@@ -103,10 +106,22 @@ sub DeviceType {
     return 'DeviceType';
 }
 
+sub ImpressionLostToBidPercent {
+    return 'ImpressionLostToBidPercent';
+}
+
 sub ImpressionLostToBudgetPercent {
     return 'ImpressionLostToBudgetPercent';
 }
 
+sub ImpressionLostToKeywordRelevancePercent {
+    return 'ImpressionLostToKeywordRelevancePercent';
+}
+
+sub ImpressionLostToLandingPageRelevancePercent {
+    return 'ImpressionLostToLandingPageRelevancePercent';
+}
+
 sub ImpressionLostToOthersPercent {
     return 'ImpressionLostToOthersPercent';
 }
