@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V8::ReportingService::Test::AdGroupPerformanceReportFilter;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -12,11 +12,12 @@ use Test::More;
 use Microsoft::AdCenter::V8::ReportingService;
 use Microsoft::AdCenter::V8::ReportingService::AdGroupPerformanceReportFilter;
 
-sub test_can_create_ad_group_performance_report_filter_and_set_all_fields : Test(5) {
+sub test_can_create_ad_group_performance_report_filter_and_set_all_fields : Test(6) {
     my $ad_group_performance_report_filter = Microsoft::AdCenter::V8::ReportingService::AdGroupPerformanceReportFilter->new
         ->AdDistribution('ad distribution')
         ->DeviceType('device type')
         ->LanguageAndRegion('language and region')
+        ->LanguageCode('language code')
         ->Status('status')
     ;
 
@@ -25,6 +26,7 @@ sub test_can_create_ad_group_performance_report_filter_and_set_all_fields : Test
     is($ad_group_performance_report_filter->AdDistribution, 'ad distribution', 'can get ad distribution');
     is($ad_group_performance_report_filter->DeviceType, 'device type', 'can get device type');
     is($ad_group_performance_report_filter->LanguageAndRegion, 'language and region', 'can get language and region');
+    is($ad_group_performance_report_filter->LanguageCode, 'language code', 'can get language code');
     is($ad_group_performance_report_filter->Status, 'status', 'can get status');
 };
 
